#!/bin/bash

if [ -e dummy.tif ]; then
	rm dummy.tif
fi

rasterizer -d dummy.tif -m image/tiff dummy.svg
EXITCODE=$?

OUTPUT_FILE_SIZE=`du -b dummy.tif | awk '{ print $1 }'`

if [ $EXITCODE -eq 0 ]; then
	# we assume that everything's OK, so file size should be >0
	if [ $OUTPUT_FILE_SIZE -eq 0 ]; then
		echo "FAIL: Although the exitcode is 0, the output is 0 sized." > /dev/stderr
		echo "BUG REPRODUCED." > /dev/stderr
		exit 1
	else
		echo "PASS: Rasterizer's exitcode is 0, please check the dummy.tif" > /dev/stderr
		echo "NO BUG APPEARED." > /dev/stderr
		exit 0
	fi
else
	# we assume that there is some error, so the size of the output file should be 0 or the file shouldn't exist
	if [ $OUTPUT_FILE_SIZE -eq 0 ]; then
		echo "WARN: Something has failed during the conversion, but rasterizer exits with proper exitcode ($EXITCODE)." > /dev/stderr
		echo "The output file has zero size." > /dev/stderr
		echo "BUG HALF REPRODUCED." > /dev/stderr
		exit 1
	else
		if [ ! -e dummy.tif ]; then
			echo "WARN: Something has failed during the conversion, but rasterizer exits with proper exitcode ($EXITCODE)." > /dev/stderr
			echo "The output file does not exist." > /dev/stderr
			echo "BUG HALF REPRODUCED." > /dev/stderr
			exit 1
		else
			echo "WARN: Rasterizer's exitcode is $EXITCODE, but the output file dummy.tif contains something. Please check the dummy.tif file." > /dev/stderr
			echo "NO BUG APPEARED." > /dev/stderr
			exit 0
		fi
	fi
fi
